@@ -32,19 +32,16 @@ class OracleOperator(BaseOperator):
         a list of str (sql statements), or reference to a template file.
         Template reference are recognized by str ending in '.sql'
         (templated)
-    :type sql: str or list[str]
     :param oracle_conn_id: The :ref:`Oracle connection id <howto/connection:oracle>`
         reference to a specific Oracle database.
-    :type oracle_conn_id: str
     :param parameters: (optional) the parameters to render the SQL query with.
-    :type parameters: dict or iterable
     :param autocommit: if True, each command is automatically committed.
         (default value: False)
-    :type autocommit: bool
     """
 
     template_fields: Sequence[str] = ('sql',)
     template_ext: Sequence[str] = ('.sql',)
+    template_fields_renderers = {'sql': 'sql'}
     ui_color = '#ededed'
 
     def __init__(
@@ -74,12 +71,9 @@ class OracleStoredProcedureOperator(BaseOperator):
     Executes stored procedure in a specific Oracle database.
 
     :param procedure: name of stored procedure to call (templated)
-    :type procedure: str
     :param oracle_conn_id: The :ref:`Oracle connection id <howto/connection:oracle>`
         reference to a specific Oracle database.
-    :type oracle_conn_id: str
     :param parameters: (optional) the parameters provided in the call
-    :type parameters: dict or iterable
     """
 
     template_fields: Sequence[str] = ('procedure',)
